.. rst-class:: detail

MoveToRobtarget
==========================

.. currentmodule:: compas_rrc

.. autoclass:: MoveToRobtarget

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~MoveToRobtarget.__init__
        ~MoveToRobtarget.from_msg
    
    